Search (Si on prend l'argent de Musk, Bezos et Arnault et qu'on le redistribue entre) | nitter

Filter
Retweets Media Videos News Verified Native videos Replies Links Images Safe Quotes Pro videos
Exclude
Retweets Media Videos News Verified Native videos Replies Links Images Safe Quotes Pro videos
Time range
-
Near

- Tweets
- Users

evpok 🏳️‍🌈 stats era retweeted
Camper Bi ~🏳️‍🌈 @cletus0297
11h
Si on prend l'argent de Musk, Bezos et Arnault et qu'on le redistribue entre 8 milliards d'êtres humains, TOUT LE MONDE recevra au moins 63.000€
10
15
33
Show this thread
Load more